@@ -16,10 +16,11 @@
 import copy
 import datetime
 import six
-import uuid
 
 import mock
+from oslo_serialization import jsonutils
 from oslo_utils import timeutils
+from oslo_utils import uuidutils
 
 from aodh import evaluator
 from aodh.evaluator import event as event_evaluator
@@ -33,7 +34,7 @@ class TestEventAlarmEvaluate(base.TestEvaluatorBase):
 
     @staticmethod
     def _alarm(**kwargs):
-        alarm_id = kwargs.get('id') or str(uuid.uuid4())
+        alarm_id = kwargs.get('id') or uuidutils.generate_uuid()
         return models.Alarm(name=kwargs.get('name', alarm_id),
                             type='event',
                             enabled=True,
@@ -55,7 +56,7 @@ class TestEventAlarmEvaluate(base.TestEvaluatorBase):
 
     @staticmethod
     def _event(**kwargs):
-        return {'message_id': kwargs.get('id') or str(uuid.uuid4()),
+        return {'message_id': kwargs.get('id') or uuidutils.generate_uuid(),
                 'event_type': kwargs.get('event_type', 'type0'),
                 'traits': kwargs.get('traits', [])}
 
@@ -122,9 +123,12 @@ class TestEventAlarmEvaluate(base.TestEvaluatorBase):
                 alarm = n['alarm']
                 event = n['event']
                 previous = n.get('previous', evaluator.UNKNOWN)
-                reason = ('Event (message_id=%(e)s) hit the query of alarm '
-                          '(id=%(a)s)' %
-                          {'e': event['message_id'], 'a': alarm.alarm_id})
+                reason = ('Event <id=%(e)s,event_type=%(type)s> hits the '
+                          'query <query=%(query)s>.') % {
+                    'e': event['message_id'],
+                    'type': event['event_type'],
+                    'query': jsonutils.dumps(alarm.rule['query'],
+                                             sort_keys=True)}
                 data = {'type': 'event', 'event': event}
                 expected = dict(alarm_id=alarm.alarm_id,
                                 state=evaluator.ALARM,
@@ -189,7 +193,7 @@ class TestEventAlarmEvaluate(base.TestEvaluatorBase):
 
     def test_skip_event_missing_event_type(self):
         alarm = self._alarm()
-        event = {'message_id': str(uuid.uuid4()), 'traits': []}
+        event = {'message_id': uuidutils.generate_uuid(), 'traits': []}
         self._do_test_event_alarm(
             [alarm], [event],
             expect_alarm_states={alarm.alarm_id: evaluator.UNKNOWN},
